# Generated by Django 2.2.24 on 2022-01-19 16:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("salary", "0015_add_zoug"),
    ]

    operations = [
        migrations.AddField(
            model_name="monthlycantonalvalidationurltranslation",
            name="label",
            field=models.CharField(blank=True, max_length=255, verbose_name="Label"),
        ),
    ]
