# Generated by Django 1.11.4 on 2017-08-22 13:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0036_userprofile_tax_jurisdiction"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="userprofile",
            managers=[],
        ),
    ]
