# Generated by Django 4.2.6 on 2025-09-24 14:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('challenge', '0084_season_availability_reminder_sent_at'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalseason',
            name='availability_reminder_sent_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Date d’envoi du rappel de disponibilités'),
        ),
    ]
