# Generated by Django 2.2.8 on 2019-12-12 13:54

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0047_userprofile_marital_status"),
    ]

    operations = [
        migrations.AlterField(
            model_name="usermanagedstate",
            name="user",
            field=models.ForeignKey(
                limit_choices_to={"is_active": True},
                on_delete=django.db.models.deletion.CASCADE,
                related_name="managedstates",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="actor_for",
            field=models.ManyToManyField(
                blank=True,
                limit_choices_to={"category": "C"},
                related_name="actor_for",
                to="challenge.QualificationActivity",
                verbose_name="Intervenant",
            ),
        ),
    ]
