# Generated by Django 2.2.9 on 2020-03-05 15:31

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0058_invoice_status_label"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="season",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="invoices",
                to="challenge.Season",
                verbose_name="Saison",
            ),
        ),
    ]
