# Generated by Django 4.2.6 on 2025-11-13 13:46

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('challenge', '0085_historicalseason_availability_reminder_sent_at'),
    ]

    operations = [
        migrations.AlterField(
            model_name='annualstatesetting',
            name='cost_per_participant',
            field=models.DecimalField(decimal_places=2, default=0, help_text='CHF', max_digits=8, validators=[django.core.validators.MinValueValidator(0)], verbose_name='Coût par participant·e·s'),
        ),
        migrations.AlterField(
            model_name='helpersessionavailability',
            name='chosen_as',
            field=models.PositiveSmallIntegerField(choices=[(0, 'Pas choisi'), (1, 'Choisi'), (2, 'Comme intervenant·e'), (5, 'Moniteur·trice de secours'), (3, 'Moniteur·trice 1'), (4, 'Moniteur·trice 2')], default=0, verbose_name='Sélectionné pour la session comme'),
        ),
        migrations.AlterField(
            model_name='historicalannualstatesetting',
            name='cost_per_participant',
            field=models.DecimalField(decimal_places=2, default=0, help_text='CHF', max_digits=8, validators=[django.core.validators.MinValueValidator(0)], verbose_name='Coût par participant·e·s'),
        ),
        migrations.AlterField(
            model_name='historicalhelpersessionavailability',
            name='chosen_as',
            field=models.PositiveSmallIntegerField(choices=[(0, 'Pas choisi'), (1, 'Choisi'), (2, 'Comme intervenant·e'), (5, 'Moniteur·trice de secours'), (3, 'Moniteur·trice 1'), (4, 'Moniteur·trice 2')], default=0, verbose_name='Sélectionné pour la session comme'),
        ),
        migrations.AlterField(
            model_name='historicalqualification',
            name='actor',
            field=models.ForeignKey(blank=True, db_constraint=False, limit_choices_to={'profile__actor_for__isnull': False}, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Intervenant·e'),
        ),
        migrations.AlterField(
            model_name='historicalqualification',
            name='class_teacher_fullname',
            field=models.CharField(blank=True, max_length=512, verbose_name='Enseignant·e'),
        ),
        migrations.AlterField(
            model_name='historicalqualification',
            name='class_teacher_natel',
            field=models.CharField(blank=True, max_length=13, verbose_name='Natel enseignant·e'),
        ),
        migrations.AlterField(
            model_name='historicalqualification',
            name='leader',
            field=models.ForeignKey(blank=True, db_constraint=False, limit_choices_to=models.Q(('profile__formation', 'M2')), null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Moniteur·trice 2'),
        ),
        migrations.AlterField(
            model_name='historicalqualification',
            name='n_helpers',
            field=models.IntegerField(choices=[(1, '1'), (2, '2'), (3, '3')], default=3, verbose_name='Nombre de moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='historicalseason',
            name='leader',
            field=models.ForeignKey(blank=True, db_constraint=False, limit_choices_to={'managedstates__isnull': False}, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Chargé·e de projet'),
        ),
        migrations.AlterField(
            model_name='historicalseason',
            name='state',
            field=models.PositiveSmallIntegerField(choices=[(1, 'Planification (invisible)'), (2, 'Annoncé (rentrée des disponibilités)'), (3, 'En cours (corrections que par les chargé·e·s de projet)'), (4, 'Terminé'), (5, 'Archivé·e')], default=1, verbose_name='État'),
        ),
        migrations.AlterField(
            model_name='historicalsession',
            name='helpers_place',
            field=models.CharField(blank=True, max_length=512, verbose_name='Lieu rendez-vous moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='historicalsession',
            name='helpers_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Heure de rendez-vous des moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='historicalsession',
            name='superleader',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Moniteur·trice + / Photographe'),
        ),
        migrations.AlterField(
            model_name='historicalsession',
            name='visible',
            field=models.BooleanField(default=False, verbose_name='Visible pour les moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='actor',
            field=models.ForeignKey(blank=True, limit_choices_to={'profile__actor_for__isnull': False}, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='qualifs_actor', to=settings.AUTH_USER_MODEL, verbose_name='Intervenant·e'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='class_teacher_fullname',
            field=models.CharField(blank=True, max_length=512, verbose_name='Enseignant·e'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='class_teacher_natel',
            field=models.CharField(blank=True, max_length=13, verbose_name='Natel enseignant·e'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='helpers',
            field=models.ManyToManyField(blank=True, limit_choices_to=models.Q(('profile__formation__in', ['M1', 'M2'])), related_name='qualifs_mon1', to=settings.AUTH_USER_MODEL, verbose_name='Moniteur·trice·s 1'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='leader',
            field=models.ForeignKey(blank=True, limit_choices_to=models.Q(('profile__formation', 'M2')), null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='qualifs_mon2', to=settings.AUTH_USER_MODEL, verbose_name='Moniteur·trice 2'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='n_helpers',
            field=models.IntegerField(choices=[(1, '1'), (2, '2'), (3, '3')], default=3, verbose_name='Nombre de moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='season',
            name='leader',
            field=models.ForeignKey(limit_choices_to={'managedstates__isnull': False}, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Chargé·e de projet'),
        ),
        migrations.AlterField(
            model_name='season',
            name='state',
            field=models.PositiveSmallIntegerField(choices=[(1, 'Planification (invisible)'), (2, 'Annoncé (rentrée des disponibilités)'), (3, 'En cours (corrections que par les chargé·e·s de projet)'), (4, 'Terminé'), (5, 'Archivé·e')], default=1, verbose_name='État'),
        ),
        migrations.AlterField(
            model_name='session',
            name='helpers_place',
            field=models.CharField(blank=True, max_length=512, verbose_name='Lieu rendez-vous moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='session',
            name='helpers_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Heure de rendez-vous des moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='session',
            name='superleader',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sess_monplus', to=settings.AUTH_USER_MODEL, verbose_name='Moniteur·trice + / Photographe'),
        ),
        migrations.AlterField(
            model_name='session',
            name='visible',
            field=models.BooleanField(default=False, verbose_name='Visible pour les moniteur·trice·s'),
        ),
        migrations.AlterField(
            model_name='historicalseason',
            name='state',
            field=models.PositiveSmallIntegerField(
                choices=[(1, 'Planification (invisible)'),
                         (2, 'Annoncé·e (rentrée des disponibilités)'),
                         (3, 'En cours (corrections que par les chargé·e·s de projet)'),
                         (4, 'Terminé·e'), (5, 'Archivé·e')], default=1,
                verbose_name='État'),
        ),
        migrations.AlterField(
            model_name='season',
            name='state',
            field=models.PositiveSmallIntegerField(
                choices=[(1, 'Planification (invisible)'),
                         (2, 'Annoncé·e (rentrée des disponibilités)'),
                         (3, 'En cours (corrections que par les chargé·e·s de projet)'),
                         (4, 'Terminé·e'), (5, 'Archivé·e')], default=1,
                verbose_name='État'),
        ),
        migrations.AlterField(
            model_name='historicalseason',
            name='state',
            field=models.PositiveSmallIntegerField(choices=[(1, 'Planification (invisible)'), (2, 'Annoncé (rentrée des disponibilités)'), (3, 'En cours (corrections que par chargé·e·s de projet)'), (4, 'Terminé'), (5, 'Archivé')], default=1, verbose_name='État'),
        ),
        migrations.AlterField(
            model_name='season',
            name='state',
            field=models.PositiveSmallIntegerField(choices=[(1, 'Planification (invisible)'), (2, 'Annoncé (rentrée des disponibilités)'), (3, 'En cours (corrections que par chargé·e·s de projet)'), (4, 'Terminé'), (5, 'Archivé')], default=1, verbose_name='État'),
        ),
    ]
