{% extends "account/base.html" %}

{% load i18n %}
{% load bootstrap3 %}
{% block head_title %}{% trans "Sign Out" %}{% endblock %}

{% block content %}
<h1>{% trans "Sign Out" %}</h1>

<p>{% trans 'Are you sure you want to sign out?' %}</p>

<form method="post" action="{% url 'account_logout' %}">
    {% csrf_token %}
    {% if redirect_field_value %}
        <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}"/>
    {% endif %}
    {% buttons %}
        <button type="submit" class="btn btn-primary">{% trans "Sign Out" %}</button>
    {% endbuttons %}
</form>
{% endblock %}
