# Generated by Django 2.2.9 on 2020-04-09 00:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("salary", "0006_data_update_timesheets"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="timesheet",
            name="time_actor",
        ),
        migrations.AddField(
            model_name="timesheet",
            name="actor_count",
            field=models.IntegerField(default=0, verbose_name="Intervention(s)"),
        ),
    ]
