{% load i18n %}
<footer id="print-footer" class="visible-print-block row small">
    <div class="col-xs-4 text-left">&nbsp;</div>
    <div class="col-xs-4 text-center">{% now "DATE_FORMAT" %}</div>
    <div class="col-xs-4 text-right"></div>
</footer>
