{% load bootstrap3 %}

<div class="form-group form-group-sm">
    {% bootstrap_label form.address_street.label label_class='col-md-3 control-label' %}

    {% bootstrap_field form.address_street size='small' field_class='col-md-6' form_group_class='none' show_label=False %}

    {% bootstrap_label form.address_no.label label_class='col-md-3 hidden-md hidden-lg control-label' %}
    {% bootstrap_field form.address_no     size='small' field_class='col-md-3' form_group_class='none' show_label=False %}
</div>
{% if has_additional and form.address_additional %}
    <div class="form-group form-group-sm">
        {% bootstrap_label form.address_additional.label label_class='col-md-3 control-label' %}
        {% bootstrap_field form.address_additional size='small' field_class='col-md-9' form_group_class='none' show_label=False  %}
    </div>
{% endif %}
<div class="form-group form-group-sm">
    {% bootstrap_label form.address_city.label label_class='col-md-3 visible-md-block visible-lg-block control-label' %}

    {% bootstrap_label form.address_zip.label label_class='col-md-3 hidden-md hidden-lg control-label' %}
    {% bootstrap_field form.address_zip       size='small' field_class='col-md-2' form_group_class='none' show_label=False %}

    {% bootstrap_label form.address_city.label label_class='col-md-3 hidden-md hidden-lg control-label' %}
    {% bootstrap_field form.address_city       size='small' field_class='col-md-5' form_group_class='none' show_label=False %}

    {% bootstrap_label form.address_canton.label label_class='col-md-3 hidden-md hidden-lg control-label' %}
    {% bootstrap_field form.address_canton       size='small' field_class='col-md-2' form_group_class='none' show_label=False %}
</div>