# Generated by Django 1.11.4 on 2017-08-24 09:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0039_rename_back"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="actor_for",
            field=models.ManyToManyField(
                blank=True,
                related_name="actor_for",
                to="challenge.QualificationActivity",
                verbose_name="Intervenant",
            ),
        ),
    ]
