# Generated by Django 2.2.24 on 2022-01-20 09:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0069_add_zoug"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="updated_at",
            field=models.DateTimeField(auto_now=True),
        ),
    ]
