table.dvqualifs-calendar {
    &>tbody {
        &>tr {
            &>td,
            &>th {
                padding-top: 0;
                padding-left: 0;
                padding-right: 0;

                a {
                    display: block;
                    padding-top: 8px;
                    padding-left: 8px;
                    padding-right: 8px;
                    padding-bottom: 10px;
                    margin-bottom: 0;
                    color: #333;
                }
            }
        }
    }
}
