# Generated by Django 2.2.16 on 2020-12-14 16:04

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0076_registration"),
    ]

    operations = [
        migrations.AddField(
            model_name="registration",
            name="is_archived",
            field=models.BooleanField(default=False, verbose_name="Archivée"),
        ),
        migrations.AlterField(
            model_name="registration",
            name="day_time",
            field=models.CharField(
                choices=[("08:30:00", "Matin"), ("13:30:00", "Après-midi")],
                default="08:30:00",
                max_length=8,
                verbose_name="Moment de la journée",
            ),
        ),
    ]
