# Generated by Django 1.11.4 on 2017-08-22 08:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0035_userprofile_formation_firstdate"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="tax_jurisdiction",
            field=models.CharField(
                blank=True,
                max_length=511,
                verbose_name="Lieu d'imposition (si pas en Suisse)",
            ),
        ),
    ]
