# Generated by Django 2.2.16 on 2020-11-03 09:34

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0070_add_months_columns"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="season",
            options={
                "ordering": ["year", "month_start", "cantons"],
                "verbose_name": "Saison",
                "verbose_name_plural": "Saisons",
            },
        ),
        migrations.RemoveField(
            model_name="historicalseason",
            name="season",
        ),
        migrations.RemoveField(
            model_name="season",
            name="season",
        ),
        migrations.AlterField(
            model_name="historicalseason",
            name="month_start",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (1, "January"),
                    (2, "February"),
                    (3, "March"),
                    (4, "April"),
                    (5, "May"),
                    (6, "June"),
                    (7, "July"),
                    (8, "August"),
                    (9, "September"),
                    (10, "October"),
                    (11, "November"),
                    (12, "December"),
                ],
                default=1,
                verbose_name="Mois de début",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="season",
            name="month_start",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (1, "January"),
                    (2, "February"),
                    (3, "March"),
                    (4, "April"),
                    (5, "May"),
                    (6, "June"),
                    (7, "July"),
                    (8, "August"),
                    (9, "September"),
                    (10, "October"),
                    (11, "November"),
                    (12, "December"),
                ],
                default=1,
                verbose_name="Mois de début",
            ),
            preserve_default=False,
        ),
    ]
