# Generated by Django 1.11.4 on 2017-08-22 13:16
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0038_multify_actor_for"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="userprofile",
            name="actor_for",
        ),
        migrations.RenameField(
            model_name="userprofile",
            old_name="actor_for_multi",
            new_name="actor_for",
        ),
    ]
