{% load i18n %}<label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %}
        class="btn btn-default{% if widget.selected %} active {% endif %}"{% if widget.disabled %} disabled title="{% trans 'Sélectionné pour une quali, impossible' %}"{% else %}
        title="{{ widget.label }}"{% endif %}
        {% if widget.class %}data-active-class="{{ widget.class }}"{% endif %}
        >
    <input type="{{ widget.type }}"
           name="{{ widget.name }}"
           {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
           {% include "django/forms/widgets/attrs.html" %} />
    {% if widget.glyphicon %}
        <span class="glyphicon glyphicon-{{ widget.glyphicon }}" {% if not widget.disabled %} title="{{ widget.label }}"{% endif %}></span>
    {% elif widget.text %}
        {{ widget.text }}
    {% endif %}
</label>
