from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0011_auto_20151009_1532"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="birthdate",
            field=models.DateField(verbose_name="Date", null=True, blank=True),
        ),
    ]
