# Generated by Django 2.2.12 on 2020-05-18 12:34

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "salary",
            "0009_monthlycantonalvalidationurl_monthlycantonalvalidationurltranslation",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="monthlycantonalvalidation",
            name="validated_urls",
            field=models.ManyToManyField(to="salary.MonthlyCantonalValidationUrl"),
        ),
    ]
