{% extends "account/base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load account %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
    <h1>{% trans "Change Password" %}</h1>
    <form method="POST" action="{% url 'account_change_password' %}" class="password_change form-horizontal">
        {% csrf_token %}
        {% bootstrap_form form layout='horizontal'%}

        {% buttons %}
            <button type="submit" class="btn btn-primary">{% trans "Change Password" %}</button>
        {% endbuttons %}
    </form>
{% endblock %}
