{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load dv_filters %}
{% block head_title %}{% blocktrans with season=season.desc %}Suppression du mois {{ season }} ?{% endblocktrans %}{% endblock %}

{% block content %}
    <h1>{% blocktrans with season=season.desc %}Suppression du mois {{ season }} ?{% endblocktrans %}</h1>

    <form method="POST" action="" class="form-horizontal">
        {% csrf_token %}
        <p>{% blocktrans with season=season.desc %}Supprimer le mois {{ season }} définitivement ?{% endblocktrans %}</p>

        {% buttons %}
            <button type="submit" class="btn btn-danger pull-right">{% trans "Supprimer vraiment" %}</button>
            <a class="btn btn-default" href="{% dv_season_url season.begin %}">{% trans "Retour à la saison" %}</a>
        {% endbuttons %}
    </form>
{% endblock %}