# Generated by Django 2.2.12 on 2020-05-20 07:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0058_userprofile_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="phone",
            field=models.CharField(blank=True, max_length=13, verbose_name="Téléphone"),
        ),
    ]
