{% extends "http_errors.html" %}
{% load i18n %}
{% block head_title %}500 {% trans "Erreur interne du serveur" %}{% endblock %}
{% block http_error_code %}500{% endblock %}
{% block http_error_name %}{% trans "Erreur interne du serveur" %}{% endblock %}
