{% extends "account/base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% load account %}

{% block head_title %}{% trans "Sign In" %}{% endblock %}

{% block content %}
    <h1>{% trans "Sign In" %}</h1>

    <form class="login form-horizontal" method="POST" action="{% url 'account_login' %}">
        {% csrf_token %}
        {% bootstrap_form form layout='horizontal' %}
        {% if redirect_field_value %}
            <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
        {% endif %}
        {% buttons %}
            <button type="submit" class="btn btn-primary">{% trans "Sign In" %}</button>
            <a class="btn btn-default" href="{% url 'account_reset_password' %}">{% trans "Forgot Password?" %}</a>
        {% endbuttons %}
    </form>
{% endblock %}