# Generated by Django 4.2.6 on 2025-12-09 10:15

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('challenge', '0087_translate_qualification_activity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalqualification',
            name='n_participants',
            field=models.PositiveSmallIntegerField(blank=True, null=True, validators=[django.core.validators.MaxValueValidator(30)], verbose_name='Nombre de participant·es'),
        ),
        migrations.AlterField(
            model_name='qualification',
            name='n_participants',
            field=models.PositiveSmallIntegerField(blank=True, null=True, validators=[django.core.validators.MaxValueValidator(30)], verbose_name='Nombre de participant·es'),
        ),
    ]
