# Generated by Django 1.11.4 on 2017-08-22 08:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0034_auto_20170821_1702"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="formation_firstdate",
            field=models.DateField(
                blank=True, null=True, verbose_name="Date de la première formation"
            ),
        ),
    ]
