# Generated by Django 3.2.14 on 2023-09-05 08:02

from django.db import migrations, models

import apps.common.fields


class Migration(migrations.Migration):
    dependencies = [
        ("user", "0072_alter_userprofile_languages_challenges"),
    ]

    operations = [
        migrations.AlterField(
            model_name="usermanagedstate",
            name="canton",
            field=models.CharField(
                choices=[
                    ("AG", "Aargau"),
                    ("AR", "Appenzell Ausserrhoden"),
                    ("BS", "Basel-Stadt"),
                    ("BL", "Basel-Land"),
                    ("BE", "Berne"),
                    ("FR", "Fribourg"),
                    ("GE", "Geneva"),
                    ("GR", "Graubuenden"),
                    ("JU", "Jura"),
                    ("LU", "Lucerne"),
                    ("NE", "Neuchatel"),
                    ("NW", "Nidwalden"),
                    ("OW", "Obwalden"),
                    ("SZ", "Schwyz"),
                    ("SO", "Solothurn"),
                    ("SG", "St. Gallen"),
                    ("VS", "Valais"),
                    ("VD", "Vaud"),
                    ("ZG", "Zug"),
                    ("ZH", "Zurich"),
                ],
                max_length=2,
                verbose_name="Canton",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="activity_cantons",
            field=apps.common.fields.ChoiceArrayField(
                base_field=models.CharField(
                    choices=[
                        ("AG", "Aargau"),
                        ("AR", "Appenzell Ausserrhoden"),
                        ("BS", "Basel-Stadt"),
                        ("BL", "Basel-Land"),
                        ("BE", "Berne"),
                        ("FR", "Fribourg"),
                        ("GE", "Geneva"),
                        ("GR", "Graubuenden"),
                        ("JU", "Jura"),
                        ("LU", "Lucerne"),
                        ("NE", "Neuchatel"),
                        ("NW", "Nidwalden"),
                        ("OW", "Obwalden"),
                        ("SZ", "Schwyz"),
                        ("SO", "Solothurn"),
                        ("SG", "St. Gallen"),
                        ("VS", "Valais"),
                        ("VD", "Vaud"),
                        ("ZG", "Zug"),
                        ("ZH", "Zurich"),
                    ],
                    max_length=2,
                ),
                blank=True,
                default=list,
                size=None,
                verbose_name="Défi Vélo mobile",
            ),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="affiliation_canton",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "---------"),
                    ("AG", "Aargau"),
                    ("AR", "Appenzell Ausserrhoden"),
                    ("BS", "Basel-Stadt"),
                    ("BL", "Basel-Land"),
                    ("BE", "Berne"),
                    ("FR", "Fribourg"),
                    ("GE", "Geneva"),
                    ("GR", "Graubuenden"),
                    ("JU", "Jura"),
                    ("LU", "Lucerne"),
                    ("NE", "Neuchatel"),
                    ("NW", "Nidwalden"),
                    ("OW", "Obwalden"),
                    ("SZ", "Schwyz"),
                    ("SO", "Solothurn"),
                    ("SG", "St. Gallen"),
                    ("VS", "Valais"),
                    ("VD", "Vaud"),
                    ("ZG", "Zug"),
                    ("ZH", "Zurich"),
                ],
                max_length=2,
                verbose_name="Canton d’affiliation",
            ),
        ),
    ]
