{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}

{% block head_title %}{% blocktrans with month_year=period %}Rappel de soumission des heures pour {{ month_year }}
{% endblocktrans %}{% endblock %}
{% block content %}
  <h1 class="page-header">
    {% blocktrans with month_year=period %}Rappel de soumission des heures pour {{ month_year }}{% endblocktrans %}
  </h1>
  <p>{% blocktrans trimmed with month_year=period %}
    Ce rappel sera envoyé aux collabora·teurs·trices qui ont participé à une session durant {{ month_year }}
    et qui n’ont pas encore soumis leurs heures.
  {% endblocktrans %}</p>

  <h3>{% trans "Contenu de l’email" %}</h3>
  <blockquote>
    <pre style="white-space: pre-wrap;">{% trans "Sujet:" %} {{ email_subject }}

{{ email_text }}</pre>
  </blockquote>
  <p>{% trans "Ce courriel sera envoyé à:" %}</p>
  <ul>
    {% for user in recipients %}
    <li>
      <a href="{% url 'user-detail' pk=user.pk %}">
        {{ user.profile.mailtolink }}
      </a>
    </li>
    {% endfor %}
  </ul>
  <form method="POST" action="{{ request.get_full_path }}">
    {% csrf_token %}
    {% buttons %}
      <button type="submit" class="btn btn-primary pull-right">{% trans 'Envoyer' %}</button>
      <a class="btn btn-default" href="{{ redirect_url }}">{% trans "Annuler" %}</a>
    {% endbuttons %}
  </form>
{% endblock %}
