{% extends "base.html" %}
{% load i18n %}
{% load bootstrap3 %}
{% block head_title %}{% blocktrans with qualification=qualification %}Suppression de la Qualif’ {{ qualification }} ?{% endblocktrans %}{% endblock %}

{% block content %}
    <h1>{% blocktrans with qualification=qualification.name %}Suppression de la Qualif’ {{ qualification }} ?{% endblocktrans %}</h1>

    <form method="POST" action="" class="form-horizontal">
        {% csrf_token %}
        <div class="panel panel-danger">
            <div class="panel-heading">
                {% trans "Confirmer" %}
            </div>
            <div class="panel-body">
                <p>{% blocktrans with qualification=qualification.name session=qualification.session %}Supprimer la Qualif’ {{ qualification }} ({{ session}}) définitivement ?{% endblocktrans %}</p>
            </div>
        </div>

        {% if timesheets %}
            {% include "challenge/_qualification_warning_timesheets.html" %}
        {% endif %}

        {% buttons %}
            <button type="submit" class="btn btn-danger pull-right">{% trans "Supprimer vraiment" %}</button>
            <a class="btn btn-default" href="{% url 'session-detail' seasonpk=season.pk pk=session.pk %}">{% trans "Retour à la liste des Qualifs" %}</a>
        {% endbuttons %}
    </form>
{% endblock %}
