# Generated by Django 1.11.4 on 2017-08-29 12:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0041_seasons_are_seasons"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="season",
            options={
                "ordering": ["year", "season"],
                "verbose_name": "Saison",
                "verbose_name_plural": "Saisons",
            },
        ),
        migrations.RemoveField(
            model_name="season",
            name="begin",
        ),
        migrations.RemoveField(
            model_name="season",
            name="end",
        ),
    ]
