# Generated by Django 2.2.16 on 2020-11-02 17:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("common", "0006_unaccented_psql"),
    ]

    operations = [
        migrations.AlterField(
            model_name="address",
            name="address_additional",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Complément d’adresse"
            ),
        ),
    ]
