# Generated by Django 4.2.6 on 2025-09-09 14:01

from django.db import migrations, models


class Migration(migrations.Migration):
    """
    The E.164 standard itself caps the national significant number at 15 digits, but libphonenumber supports up to 17 digits in practice because some numbering plans exceed the formal limit
    """
    dependencies = [
        ("user", "0074_alter_userprofile_iban"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="natel",
            field=models.CharField(blank=True, max_length=17),
        ),
        migrations.AlterField(
            model_name="userprofile",
            name="phone",
            field=models.CharField(blank=True, max_length=17, verbose_name="Téléphone"),
        ),
    ]
