# Generated by Django 2.2.16 on 2020-10-27 16:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0066_invoicelines_with_nullable_sessions"),
        ("challenge", "0066_add_schwyz"),
    ]

    operations = []
