{% extends "base.html" %}
{% load i18n bootstrap3 dv_filters %}
{% block head_title %}{{ season.desc }}{% endblock %}

{% block content %}
    {% include "challenge/season_header.html" with season=season only %}
    <h4>{% trans "Toutes les sessions" %}</h4>

    <table class="table">
    {% for session in sessions_by_orga %}
        {% ifchanged session.orga %}
            <tr><th colspan="3">{{ session.orga }}</th></tr>
        {% endifchanged %}
        {% include "challenge/session_item_in_list.html" with session=session season=season user=request.user only %}
    {% endfor %}
    </table>

    {% include "challenge/session_list_links.html" %}
{% endblock %}
