# Generated by Django 2.2.16 on 2020-10-28 13:21

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("challenge", "0071_remove_season"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalseason",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Mois",
            },
        ),
        migrations.AlterModelOptions(
            name="season",
            options={
                "ordering": ["year", "month_start", "cantons"],
                "verbose_name": "Mois",
                "verbose_name_plural": "Mois",
            },
        ),
        migrations.AlterField(
            model_name="helperseasonworkwish",
            name="season",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="work_wishes",
                to="challenge.Season",
                verbose_name="Mois",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhelperseasonworkwish",
            name="season",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="challenge.Season",
                verbose_name="Mois",
            ),
        ),
        migrations.AlterField(
            model_name="invoice",
            name="season",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="invoices",
                to="challenge.Season",
                verbose_name="Mois",
            ),
        ),
    ]
